@@ -2,19 +2,27 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Notas",
+    "New note" : "Nuwe nota",
     "Encryption Error" : "Enkripsiefout",
     "Error" : "Fout",
-    "New note" : "Nuwe nota",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Daar is ongestoorde veranderinge. Indien die bladsy gesluit word sal alle veranderinge geskrap word!",
     "Settings" : "Instellings",
     "path to notes" : "pad na notas",
     "File extension for new notes" : "Lêeruitbreiding vir nuwe notas",
     "All notes" : "Alle notas",
     "Categories" : "Kategorieë",
+    "Today" : "Vandag",
+    "Yesterday" : "Gister",
     "Delete note" : "Skrap nota",
+    "Remove from favorites" : "Verwyder uit gunstelinge",
+    "Add to favorites" : "Voeg by gunstelinge",
+    "Details" : "Besonderhede",
+    "Edit" : "Wysig",
     "Category" : "Kategorie",
     "Uncategorized" : "Ongekategorieseer",
     "Saving failed!" : "Stoor het misluk!",
-    "_%n word_::_%n words_" : ["%n woord","%n woorde"]
+    "_%n word_::_%n words_" : ["%n woord","%n woorde"],
+    "Android app" : "Android-toep",
+    "iOS app" : "iOS-toep"
 },
 "nplurals=2; plural=(n != 1);");
