@@ -2,19 +2,32 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Σημειώσεις",
+    "New note" : "Νέα σημείωση",
     "Encryption Error" : "Σφάλμα κρυπτογράφησης",
     "Error" : "Σφάλμα",
-    "New note" : "Νέα σημείωση",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν επισημάνσεις που δεν έχουν αποθηκευτεί. Αφήνοντας τη σελίδα θα διαγραφούν όλες οι αλλαγές!",
     "Settings" : "Ρυθμίσεις",
     "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
     "path to notes" : "διαδρομή στις σημειώσεις",
     "All notes" : "Όλες οι σημειώσεις",
     "Categories" : "Κατηγορίες",
+    "Today" : "Σήμερα",
+    "Yesterday" : "Χθές",
+    "This week" : "Αυτή την εβδομάδα",
+    "Last week" : "Προηγούμενη εβδομάδα",
+    "This month" : "Αυτό το μήνα",
+    "Last month" : "Προηγούμενος μήνας",
     "Delete note" : "Διαγραφή σημείωσης",
+    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
+    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
+    "Details" : "Λεπτομέρειες",
+    "Preview" : "Προεπισκόπηση",
+    "Edit" : "Επεξεργασία",
     "Category" : "Κατηγορία",
     "Uncategorized" : "Μή-κατηγοριοποιημένα",
     "Saving failed!" : "Απέτυχε η αποθήκευση!",
-    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"]
+    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
+    "Android app" : "Εφαρμογή Android",
+    "iOS app" : "Εφαρμογή iOS"
 },
 "nplurals=2; plural=(n != 1);");
