@@ -4,9 +4,9 @@ OC.L10N.register(
     "Notes" : "Заметки",
     "The last viewed note cannot be accessed. " : "Не удалось перейти к последней просмотренной заметке",
     "The notes folder is not accessible: %s" : "Папка заметок недоступна: %s",
+    "New note" : "Новая заметка",
     "Encryption Error" : "Ошибка шифрования",
     "Error" : "Ошибка",
-    "New note" : "Новая заметка",
     "Distraction-free notes and writing" : "Простые заметки и записки",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Заметка не сохранены. Если покинуть страницу, все изменения будут удалены!",
     "Settings" : "Параметры",
@@ -15,11 +15,22 @@ OC.L10N.register(
     "File extension for new notes" : "Расширения файла для новых заметок",
     "All notes" : "Все заметки",
     "Categories" : "Категории",
+    "Today" : "Сегодня",
+    "Yesterday" : "Вчера",
+    "This week" : "Эта неделя",
+    "This month" : "Этот месяц",
     "Delete note" : "Удалить заметку",
+    "Remove from favorites" : "Удалить из избранного",
+    "Add to favorites" : "Добавить в избранное",
+    "Details" : "Подробнее",
+    "Preview" : "Предварительный просмотр",
+    "Edit" : "Редактировать",
     "Category" : "Категория",
     "Uncategorized" : "Без категории",
     "Saving failed!" : "Ошибка при сохранении!",
     "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
+    "Android app" : "Android приложение",
+    "iOS app" : "iOS приложение",
     "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
