@@ -4,9 +4,9 @@ OC.L10N.register(
     "Notes" : "Anteckningar",
     "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
     "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
+    "New note" : "Ny anteckning",
     "Encryption Error" : "Krypteringsfel",
     "Error" : "Fel",
-    "New note" : "Ny anteckning",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "Settings" : "Inställningar",
@@ -15,19 +15,20 @@ OC.L10N.register(
     "File extension for new notes" : "Filtillägg för nya anteckningar",
     "All notes" : "Alla anteckningar",
     "Categories" : "Kategorier",
-    "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
-    "Search result for “{search}”" : "Sökresultat för “{search}”",
     "No search result for “{search}” in {category}" : "Inget sökresultat för “{search}” i {category}",
     "No search result for “{search}”" : "Inget sökresultat för “{search}”",
+    "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
+    "Search result for “{search}”" : "Sökresultat för “{search}”",
     "Today" : "Idag",
     "Yesterday" : "Igår",
     "This week" : "Denna vecka",
     "Last week" : "Förra veckan",
     "This month" : "Denna månad",
     "Last month" : "Förra månaden",
+    "Delete note" : "Radera anteckning",
+    "Deleted {title}" : "Raderad {title}",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
-    "Delete note" : "Radera anteckning",
     "Empty note" : "Tom anteckning",
     "Write …" : "Skriv ...",
     "Details" : "Detaljer",
@@ -62,6 +63,7 @@ OC.L10N.register(
     "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
     "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
     "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
-    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades."
+    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
+    "Development Mode" : "Utvecklingsläge"
 },
 "nplurals=2; plural=(n != 1);");
